Array

Trait Array 

pub trait Array: Sealed {
    type Value;

    const LENGTH: usize;
}
Representation of an enum, which can only be an array.

Required Associated Constants

const LENGTH: usize

Number of elements in an enum.

Required Associated Types

type Value

Type of elements stored in an array representation of an enum.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<V, const N: usize> Array for [V; N]

Implementors